@@ -5,6 +5,7 @@
 use crate::*;
 
 pub use commute as symmetry;
+pub use neq_commute as neq_symmetry;
 
 /// `(a = b) ∧ (b = c) => (a = c)`.
 pub fn transitivity<A: Prop, B: Prop, C: Prop>((f0, f1): Eq<A, B>, (g0, g1): Eq<B, C>) -> Eq<A, C> {
@@ -22,6 +23,11 @@ pub fn commute<A: Prop, B: Prop>((f0, f1): Eq<A, B>) -> Eq<B, A> {
     (f1, f0)
 }
 
+/// `¬(a = b) => ¬(b = a)`.
+pub fn neq_commute<A: Prop, B: Prop>(neq: Not<Eq<A, B>>) -> Not<Eq<B, A>> {
+    Rc::new(move |eq| neq(commute(eq)))
+}
+
 /// `(a => b) = (¬a ∨ b)`.
 pub fn imply_to_or<A: DProp, B: DProp>() -> Eq<Imply<A, B>, Or<Not<A>, B>> {
     (Rc::new(move |x| imply::to_or(x)), Rc::new(move |x| imply::from_or(x)))
@@ -190,3 +196,19 @@ pub fn inv_triangle<A: DProp, B: DProp, C: DProp>(
 pub fn absurd() -> Eq<False, False> {
     (imply::absurd(), imply::absurd())
 }
+
+/// `(a == b) ⋀ ¬(a == c) => ¬(b == c)`.
+pub fn neq_left<A: Prop, B: Prop, C: Prop>(
+    eq_ab: Eq<A, B>,
+    neq_ac: Not<Eq<A, C>>
+) -> Not<Eq<B, C>> {
+    Rc::new(move |eq_bc| neq_ac(transitivity(eq_ab.clone(), eq_bc)))
+}
+
+/// `(a == b) ⋀ ¬(b == c) => ¬(a == c)`.
+pub fn neq_right<A: Prop, B: Prop, C: Prop>(
+    eq_ab: Eq<A, B>,
+    neq_bc: Not<Eq<B, C>>
+) -> Not<Eq<A, C>> {
+    Rc::new(move |eq_ac| neq_bc(transitivity(commute(eq_ab.clone()), eq_ac)))
+}
